/**
 * Copyright (c) 2025 Dominic Masters
 * 
 * This software is released under the MIT License.
 * https://opensource.org/licenses/MIT
 */

#pragma once
#include "eventdata.h"

typedef struct {
  eventdata_t data;
  const eventdata_t *active;
  uint8_t item;
} event_t;

typedef struct {
  void (*start)(const eventitem_t *item);
  void (*update)(const eventitem_t *item);
} eventcallback_t;

extern eventcallback_t EVENT_CALLBACKS[EVENT_TYPE_COUNT];
extern event_t EVENT;

/**
 * Initializes the event system.
 */
void eventInit();

/**
 * Updates the active event.
 */
void eventUpdate();

/**
 * Sets the active event.
 * 
 * @param event The event to set as active.
 */
void eventSetActive(const eventdata_t *eventData);

/**
 * Goes to the next item in the active event. Only meant to be called by
 * event items.
 */
void eventNext();